Date: 03 23, 2002 4:59:01 AM

# singlex

## Purpose

Perform a single tier reduction of a range of rule elements. All nodes NOT in the range are EXCISED.

## Syntax

singlex(number1, number2)

number1 - type: int
number2 - type: int

## Returns

## Remarks

## Example

# Reduce the _det and _noun to an _np.
# REMOVE the node that matched element 3
# from the parse tree.
@POST
singlex(1,2);
@RULES
_np <- _det _noun _xWILD [one fail=(_noun)] @@

## See Also

singlezap, single, singler, noop, POST Actions